summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/gwmessagemanager.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
commit9c9412b30c54468adc9e506cc76c5d113fbf5056 (patch)
tree68a0c0d5bc770fc58596b8c5624cdf33d8625027 /kopete/protocols/groupwise/gwmessagemanager.cpp
parent2e53bd0b77676f879fad7baeecea5879bf496a7d (diff)
downloadtdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.tar.gz
tdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kopete/protocols/groupwise/gwmessagemanager.cpp')
-rw-r--r--kopete/protocols/groupwise/gwmessagemanager.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kopete/protocols/groupwise/gwmessagemanager.cpp b/kopete/protocols/groupwise/gwmessagemanager.cpp
index 100bbfdf..eef88a7b 100644
--- a/kopete/protocols/groupwise/gwmessagemanager.cpp
+++ b/kopete/protocols/groupwise/gwmessagemanager.cpp
@@ -62,13 +62,13 @@ GroupWiseChatSession::GroupWiseChatSession(const Kopete::Contact* user, Kopete::
TQT_SLOT( slotGotNotTypingNotification( const ConferenceEvent & ) ) );
// Set up the Invite menu
- m_actionInvite = new KActionMenu( i18n( "&Invite" ), actionCollection() , "gwInvite" );
+ m_actionInvite = new TDEActionMenu( i18n( "&Invite" ), actionCollection() , "gwInvite" );
connect( m_actionInvite->popupMenu(), TQT_SIGNAL( aboutToShow() ), this, TQT_SLOT(slotActionInviteAboutToShow() ) ) ;
- m_secure = new KAction( i18n( "Security Status" ), "encrypted", KShortcut(), this, TQT_SLOT( slotShowSecurity() ), actionCollection(), "gwSecureChat" );
+ m_secure = new TDEAction( i18n( "Security Status" ), "encrypted", TDEShortcut(), this, TQT_SLOT( slotShowSecurity() ), actionCollection(), "gwSecureChat" );
m_secure->setToolTip( i18n( "Conversation is secure" ) );
- m_logging = new KAction( i18n( "Archiving Status" ), "logchat", KShortcut(), this, TQT_SLOT( slotShowArchiving() ), actionCollection(), "gwLoggingChat" );
+ m_logging = new TDEAction( i18n( "Archiving Status" ), "logchat", TDEShortcut(), this, TQT_SLOT( slotShowArchiving() ), actionCollection(), "gwLoggingChat" );
updateArchiving();
setXMLFile("gwchatui.rc");
@@ -295,7 +295,7 @@ void GroupWiseChatSession::dequeueMessagesAndInvites()
void GroupWiseChatSession::slotActionInviteAboutToShow()
{
// We can't simply insert KAction in this menu bebause we don't know when to delete them.
// items inserted with insert items are automatically deleted when we call clear
m_inviteActions.setAutoDelete(true);
@@ -309,14 +309,14 @@ void GroupWiseChatSession::slotActionInviteAboutToShow()
{
if( !members().contains( it.current() ) && it.current()->isOnline() && it.current() != myself() )
{
- KAction *a=new KopeteContactAction( it.current(), this,
+ TDEAction *a=new KopeteContactAction( it.current(), this,
TQT_SLOT( slotInviteContact( Kopete::Contact * ) ), m_actionInvite );
m_actionInvite->insert( a );
m_inviteActions.append( a ) ;
}
}
// Invite someone off-list
- KAction *b=new KAction( i18n ("&Other..."), 0, this, TQT_SLOT( slotInviteOtherContact() ), m_actionInvite, "actionOther" );
+ TDEAction *b=new TDEAction( i18n ("&Other..."), 0, this, TQT_SLOT( slotInviteOtherContact() ), m_actionInvite, "actionOther" );
m_actionInvite->insert( b );
m_inviteActions.append( b ) ;
}
@@ -330,7 +330,7 @@ void GroupWiseChatSession::slotInviteContact( Kopete::Contact * contact )
}
else
{
- TQWidget * w = view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 0L;
+ TQWidget * w = view(false) ? dynamic_cast<TDEMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 0L;
bool ok;
TQRegExp rx( ".*" );
@@ -358,7 +358,7 @@ void GroupWiseChatSession::slotInviteOtherContact()
if ( !m_searchDlg )
{
// show search dialog
- TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
+ TQWidget * w = ( view(false) ? dynamic_cast<TDEMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
Kopete::UI::Global::mainWidget() );
m_searchDlg = new KDialogBase( w, "invitesearchdialog", false, i18n( "Search for Contact to Invite" ), KDialogBase::Ok|KDialogBase::Cancel );
m_search = new GroupWiseContactSearch( account(), TQListView::Single, true, m_searchDlg, "invitesearchwidget" );
@@ -375,7 +375,7 @@ void GroupWiseChatSession::slotSearchedForUsers()
TQValueList< ContactDetails > selected = m_search->selectedResults();
if ( selected.count() )
{
- TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
+ TQWidget * w = ( view(false) ? dynamic_cast<TDEMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
Kopete::UI::Global::mainWidget() );
ContactDetails cd = selected.first();
bool ok;
@@ -501,14 +501,14 @@ void GroupWiseChatSession::updateArchiving()
void GroupWiseChatSession::slotShowSecurity()
{
- TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
+ TQWidget * w = ( view(false) ? dynamic_cast<TDEMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
Kopete::UI::Global::mainWidget() );
KMessageBox::queuedMessageBox( w, KMessageBox::Information, i18n( "This conversation is secured with SSL security." ), i18n("Security Status" ) );
}
void GroupWiseChatSession::slotShowArchiving()
{
- TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
+ TQWidget * w = ( view(false) ? dynamic_cast<TDEMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
Kopete::UI::Global::mainWidget() );
KMessageBox::queuedMessageBox( w, KMessageBox::Information, i18n( "This conversation is being logged administratively." ), i18n("Archiving Status" ) );
}
@@ -295,7 +295,7 @@ void GroupWiseChatSession::dequeueMessagesAndInvites()
void GroupWiseChatSession::slotActionInviteAboutToShow()
{
- // We can't simply insert KAction in this menu bebause we don't know when to delete them.
+ // We can't simply insert TDEAction in this menu bebause we don't know when to delete them.
// items inserted with insert items are automatically deleted when we call clear
m_inviteActions.setAutoDelete(true);